==> org.eclipse.justj.openjdk.hotspot.jre.full-11.0.15-macosx-x86_64.tar.gz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_fr_CA.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_fr_CA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ARS", "ARS" },
            { "AUD", "$\u00a0AU" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BSD", "BSD" },
            { "BZD", "BZD" },
            { "CAD", "$" },
            { "CLP", "CLP" },
            { "CNY", "CN\u00a5" },
            { "COP", "COP" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GBP", "\u00a3" },
            { "GIP", "GIP" },
            { "HKD", "$\u00a0HK" },
            { "ILS", "ILS" },
            { "INR", "INR" },
            { "JPY", "\u00a5" },
            { "KRW", "KRW" },
            { "LBP", "LBP" },
            { "MXN", "MXN" },
            { "NAD", "NAD" },
            { "NZD", "$\u00a0NZ" },
            { "SBD", "SBD" },
            { "SGD", "$\u00a0SG" },
            { "SRD", "SRD" },
            { "TTD", "TTD" },
            { "USD", "$\u00a0US" },
            { "UYU", "UYU" },
            { "VND", "VND" },
            { "XAF", "XAF" },
            { "XOF", "XOF" },
            { "XPF", "XPF" },
            { "fkp", "livre des \u00celes Malouines" },
            { "irr", "rial iranien" },
            { "omr", "rial omanais" },
            { "sar", "rial saoudien" },
            { "top", "pa\u2019anga" },
            { "ttd", "dollar de Trinit\u00e9-et-Tobago" },
            { "xxx", "Devise inconnue" },
            { "yer", "rial y\u00e9m\u00e9nite" },
        };
        return data;
    }
}

==> org.eclipse.justj.openjdk.hotspot.jre.full-21.0.1-macosx-x86_64.tar.gz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_fr_CA.java <==
/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_fr_CA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ARS", "ARS" },
            { "AUD", "$\u00a0AU" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BZD", "BZD" },
            { "CAD", "$" },
            { "CLP", "CLP" },
            { "CNY", "CN\u00a5" },
            { "COP", "COP" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GBP", "\u00a3" },
            { "GIP", "GIP" },
            { "HKD", "$\u00a0HK" },
            { "ILS", "ILS" },
            { "INR", "INR" },
            { "JPY", "\u00a5" },
            { "KRW", "KRW" },
            { "LBP", "LBP" },
            { "MXN", "MXN" },
            { "NAD", "NAD" },
            { "NZD", "$\u00a0NZ" },
            { "SBD", "SBD" },
            { "SGD", "$\u00a0SG" },
            { "SRD", "SRD" },
            { "TTD", "TTD" },
            { "USD", "$\u00a0US" },
            { "UYU", "UYU" },
            { "VND", "VND" },
            { "WST", "WST" },
            { "XAF", "XAF" },
            { "XOF", "XOF" },
            { "XPF", "XPF" },
            { "azn", "manat azerba\u00efdjanais" },
            { "cve", "escudo cap-verdien" },
            { "irr", "rial iranien" },
            { "omr", "rial omanais" },
            { "pen", "nouveau sol p\u00e9ruvien" },
            { "pgk", "kina papou-n\u00e9o-guin\u00e9en" },
            { "qar", "riyal du Qatar" },
            { "sar", "rial saoudien" },
            { "srd", "dollar du Suriname" },
            { "top", "pa\u2019anga" },
            { "vuv", "vatu" },
            { "wst", "tala" },
            { "xxx", "Devise inconnue" },
            { "yer", "rial y\u00e9m\u00e9nite" },
        };
        return data;
    }
}
